@@ -523,6 +523,10 @@ HelpAboutForm::HelpAboutForm(QWidget* parent): QDialog(parent)
 	references+=QString("28. https://stackoverflow.com/questions/10053839/how-does-designer-create-a-line-widget");
 	references+=QString("<br /><br />");
 	references+=QString("29. Google Translate: https://translate.google.com/");
+	references+=QString("<br /><br />");
+	references+=QString("30. https://forum.qt.io/topic/94474/how-to-add-a-spinbox-column-and-combo-box-column-in-qtablewidget-or-qtableview");
+	references+=QString("<br /><br />");
+	references+=QString("31. https://stackoverflow.com/questions/35435254/refer-to-the-sender-object-in-qt");
 
 	references+=QString("<br /><br /><br />");
 
@@ -1483,6 +1487,16 @@ HelpAboutForm::HelpAboutForm(QWidget* parent): QDialog(parent)
 	thanksTo+=QString("<br />");
 	thanksTo+=QString("Youssef Bourdha");
 	thanksTo+=QString("<br />");
+	thanksTo+=QString("Mo Da");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("Aboulhamid");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("islam");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("thiagonunes");
+	thanksTo+=QString("<br />");
+	thanksTo+=QString("Anisse Hanifi");
+	thanksTo+=QString("<br />");
 	
 	thanksToTextBrowser->setHtml(thanksTo);
 }
